@@ -40,7 +40,7 @@ if t_.TYPE_CHECKING:
     from ..utility.reflection import Material
 
 
-class ICBase(ABC): #TODO add a `completeNormalization` method
+class ICBase(ABC):
     """A class to handle the data operations common to PWS related `image cubes`. Does not contain any file specific
     functionality. uses the generic `index` attribute which can be overridden by derived classes to be wavelength, wavenumber,
     time, etc.
@@ -76,6 +76,7 @@ class ICBase(ABC): #TODO add a `completeNormalization` method
         """
         return self._index
 
+
     def plotMean(self) -> t_.Tuple[plt.Figure, plt.Axes]:
         """
 
@@ -107,7 +108,7 @@ class ICBase(ABC): #TODO add a `completeNormalization` method
         std = self.data[mask].std(axis=0)
         return mean, std
 
-    def selectLassoROI(self, displayIndex: t_.Optional[int] = None, clim: t_.Sequence = None) -> np.ndarray:
+    def selectLassoROI(self, displayIndex: t_.Optional[int] = None, clim: t_.Sequence = None) -> _other.Roi:
         """
         Allow the user to draw a `freehand` ROI on an image of the acquisition.
 
@@ -134,7 +135,7 @@ class ICBase(ABC): #TODO add a `completeNormalization` method
         fig.show()
         while plt.fignum_exists(fig.number):
             fig.canvas.flush_events()
-        return np.array(Verts[0])
+        return _other.Roi.fromVerts(np.array(Verts[0]), self.data.shape[:2])
 
     def selectRectangleROI(self, displayIndex: t_.Optional[int] = None) -> np.ndarray:
         """
@@ -383,14 +384,14 @@ class ICRawBase(ICBase, ABC):
 
     def normalizeByExposure(self):
         """This is one of the first steps in most analysis pipelines. Data is divided by the camera exposure.
-        This way two ImCube that were acquired at different exposure times will still be on equivalent scales."""
+        This way two PwsCube that were acquired at different exposure times will still be on equivalent scales."""
         if not self.processingStatus.cameraCorrected:
             raise Exception(
-                "This ImCube has not yet been corrected for camera effects. are you sure you want to normalize by exposure?")
+                "This PwsCube has not yet been corrected for camera effects. are you sure you want to normalize by exposure?")
         if not self.processingStatus.normalizedByExposure:
             self.data = self.data / self.metadata.exposure
         else:
-            raise Exception("The ImCube has already been normalized by exposure.")
+            raise Exception("The PwsCube has already been normalized by exposure.")
         self.processingStatus.normalizedByExposure = True
 
     def correctCameraEffects(self, correction: _other.CameraCorrection = None, binning: int = None):
@@ -403,7 +404,7 @@ class ICRawBase(ICBase, ABC):
             binning: The binning that the raw data was imaged at. 2 = 2x2 binning, 3 = 3x3 binning, etc.
         """
         if self.processingStatus.cameraCorrected:
-            raise Exception("This ImCube has already had it's camera correction applied!")
+            raise Exception("This PwsCube has already had it's camera correction applied!")
         if binning is None:
             binning = self.metadata.binning
             if binning is None: raise ValueError('Binning metadata not found. Binning must be specified in function argument.')
@@ -539,7 +540,7 @@ class DynCube(ICRawBase):
 
     _hdfTypeName = "DynCube"  # This is used for saving/loading from HDF. Important not to change it or old files will stop working.
 
-    def __init__(self, data, metadata: pwsdtmd.DynMetaData, processingStatus: ICRawBase.ProcessingStatus=None, dtype=np.float32):
+    def __init__(self, data, metadata: pwsdtmd.DynMetaData, processingStatus: ICRawBase.ProcessingStatus = None, dtype=np.float32):
         assert isinstance(metadata, pwsdtmd.DynMetaData)
         super().__init__(data, metadata.times, metadata, processingStatus=processingStatus, dtype=dtype)
 
@@ -856,7 +857,7 @@ class ExtraReflectionCube(ICBase):
         self.metadata = metadata
 
     @classmethod
-    def create(cls, reflectance: ExtraReflectanceCube, theoryR: pd.Series, reference: ImCube) -> ExtraReflectionCube:
+    def create(cls, reflectance: ExtraReflectanceCube, theoryR: pd.Series, reference: PwsCube) -> ExtraReflectionCube:
         """
         Construct and ExtraReflectionCube from an ExtraReflectanceCube and a reference measurement. The resulting
         ExtraReflectionCube will be in the same units as `reference`. `theoryR` should be a spectrum describing the theoretically
@@ -875,7 +876,7 @@ class ExtraReflectionCube(ICBase):
         return cls(data, reflectance.wavelengths, reflectance.metadata)
 
 
-class ImCube(ICRawBase):
+class PwsCube(ICRawBase):
     """
     A class representing a single PWS acquisition. Contains methods for loading and saving to multiple formats as
     well as common operations used in analysis.
@@ -890,8 +891,8 @@ class ImCube(ICRawBase):
 
     _hdfTypeName = "ImCube"  # This is used for saving/loading from HDF. Important not to change it or old files will stop working.
 
-    def __init__(self, data, metadata: pwsdtmd.ICMetaData, processingStatus: ICRawBase.ProcessingStatus=None, dtype=np.float32):
-        assert isinstance(metadata, pwsdtmd.ICMetaData)
+    def __init__(self, data, metadata: pwsdtmd.PwsMetaData, processingStatus: ICRawBase.ProcessingStatus = None, dtype=np.float32):
+        assert isinstance(metadata, pwsdtmd.PwsMetaData)
         super().__init__(data, metadata.wavelengths, metadata, processingStatus=processingStatus, dtype=dtype)
 
     @property
@@ -902,9 +903,9 @@ class ImCube(ICRawBase):
         return self.index
 
     @classmethod
-    def loadAny(cls, directory: str, metadata: pwsdtmd.ICMetaData = None,  lock: mp.Lock = None):
+    def loadAny(cls, directory: str, metadata: pwsdtmd.PwsMetaData = None, lock: mp.Lock = None):
         """
-        Attempt to load a `ImCube` for any format of file in `directory`
+        Attempt to load a `PwsCube` for any format of file in `directory`
 
         Args:
             directory: The directory containing the data files.
@@ -912,21 +913,21 @@ class ImCube(ICRawBase):
             lock: A `Lock` object used to synchronized IO in multithreading and multiprocessing applications.
 
         Returns:
-            A new instance of `ImCube`.
+            A new instance of `PwsCube`.
         """
         try:
-            return ImCube.fromTiff(directory, metadata=metadata, lock=lock)
+            return PwsCube.fromTiff(directory, metadata=metadata, lock=lock)
         except:
             try:
-                return ImCube.fromOldPWS(directory, metadata=metadata, lock=lock)
+                return PwsCube.fromOldPWS(directory, metadata=metadata, lock=lock)
             except:
                 try:
-                    return ImCube.fromNano(directory, metadata=metadata, lock=lock)
+                    return PwsCube.fromNano(directory, metadata=metadata, lock=lock)
                 except:
                     raise OSError(f"Could not find a valid PWS image cube file at {directory}.")
 
     @classmethod
-    def fromOldPWS(cls, directory: str, metadata: pwsdtmd.ICMetaData = None,  lock: mp.Lock = None):
+    def fromOldPWS(cls, directory: str, metadata: pwsdtmd.PwsMetaData = None, lock: mp.Lock = None):
         """
         Loads from the file format that was saved by the all-matlab version of the Basis acquisition code.
         Data was saved in raw binary to a file called `image_cube`. Some metadata was saved to .mat files called
@@ -938,13 +939,13 @@ class ImCube(ICRawBase):
             lock: A `Lock` object used to synchronized IO in multithreading and multiprocessing applications.
 
         Returns:
-            A new instance of `ImCube`.
+            A new instance of `PwsCube`.
         """
         if lock is not None:
             lock.acquire()
         try:
             if metadata is None:
-                metadata = pwsdtmd.ICMetaData.fromOldPWS(directory)
+                metadata = pwsdtmd.PwsMetaData.fromOldPWS(directory)
             with open(os.path.join(directory, 'image_cube'), 'rb') as f:
                 data = np.frombuffer(f.read(), dtype=np.uint16)
             data = data.reshape((metadata.dict['imgHeight'], metadata.dict['imgWidth'], len(metadata.wavelengths)), order='F')
@@ -955,7 +956,7 @@ class ImCube(ICRawBase):
         return cls(data, metadata)
 
     @classmethod
-    def fromTiff(cls, directory, metadata: pwsdtmd.ICMetaData = None,  lock: mp.Lock = None):
+    def fromTiff(cls, directory, metadata: pwsdtmd.PwsMetaData = None, lock: mp.Lock = None):
         """
         Loads from a 3D tiff file named `pws.tif`, or in some older data `MMStack.ome.tif`. Metadata can be stored in
         the tags of the tiff file but if there is a pwsmetadata.json file found then this is preferred.
@@ -968,13 +969,13 @@ class ImCube(ICRawBase):
             lock: A `Lock` object used to synchronized IO in multithreading and multiprocessing applications.
 
         Returns:
-            A new instance of `ImCube`.
+            A new instance of `PwsCube`.
         """
         if lock is not None:
             lock.acquire()
         try:
             if metadata is None:
-                metadata = pwsdtmd.ICMetaData.fromTiff(directory)
+                metadata = pwsdtmd.PwsMetaData.fromTiff(directory)
             if os.path.exists(os.path.join(directory, 'MMStack.ome.tif')):
                 path = os.path.join(directory, 'MMStack.ome.tif')
             elif os.path.exists(os.path.join(directory, 'pws.tif')):
@@ -990,9 +991,9 @@ class ImCube(ICRawBase):
         return cls(data, metadata)
 
     @classmethod
-    def fromNano(cls, directory: str, metadata: pwsdtmd.ICMetaData = None, lock: mp.Lock = None) -> ImCube:
+    def fromNano(cls, directory: str, metadata: pwsdtmd.PwsMetaData = None, lock: mp.Lock = None) -> PwsCube:
         """
-        Loads from the file format used at NanoCytomics. all data and metadata is contained in a .mat file.
+        Loads from the file format used at NC. all data and metadata is contained in a .mat file.
 
         Args:
             directory: The directory containing the data files.
@@ -1000,14 +1001,14 @@ class ImCube(ICRawBase):
             lock: A `Lock` object used to synchronized IO in multithreading and multiprocessing applications.
 
         Returns:
-            A new instance of `ImCube`.
+            A new instance of `PwsCube`.
         """
         path = os.path.join(directory, 'imageCube.mat')
         if lock is not None:
             lock.acquire()
         try:
             if metadata is None:
-                metadata = pwsdtmd.ICMetaData.fromNano(directory)
+                metadata = pwsdtmd.PwsMetaData.fromNano(directory)
             with h5py.File(path, 'r') as hf:
                 data = np.array(hf['imageCube'])
                 data = data.transpose((2, 1, 0))  # Re-order axes to match the shape of ROIs and thumbnails.
@@ -1018,24 +1019,24 @@ class ImCube(ICRawBase):
         return cls(data, metadata)
 
     @classmethod
-    def fromMetadata(cls, meta: pwsdtmd.ICMetaData,  lock: mp.Lock = None) -> ImCube:
+    def fromMetadata(cls, meta: pwsdtmd.PwsMetaData, lock: mp.Lock = None) -> PwsCube:
         """
-        If provided with an ICMetadata object this function will automatically select the correct file loading method
-        and will return the associated ImCube.
+        If provided with an PwsMetaData object this function will automatically select the correct file loading method
+        and will return the associated PwsCube.
 
         Args:
             meta: The metadata to use to load the object from.
             lock: A `Lock` object used to synchronized IO in multithreading and multiprocessing applications.
 
         Returns:
-            A new instance of `ImCube`.
+            A new instance of `PwsCube`.
         """
-        assert isinstance(meta, pwsdtmd.ICMetaData)
-        if meta.fileFormat == pwsdtmd.ICMetaData.FileFormats.Tiff:
+        assert isinstance(meta, pwsdtmd.PwsMetaData)
+        if meta.fileFormat == pwsdtmd.PwsMetaData.FileFormats.Tiff:
             return cls.fromTiff(meta.filePath, metadata=meta, lock=lock)
-        elif meta.fileFormat == pwsdtmd.ICMetaData.FileFormats.RawBinary:
+        elif meta.fileFormat == pwsdtmd.PwsMetaData.FileFormats.RawBinary:
             return cls.fromOldPWS(meta.filePath, metadata=meta, lock=lock)
-        elif meta.fileFormat == pwsdtmd.ICMetaData.FileFormats.NanoMat:
+        elif meta.fileFormat == pwsdtmd.PwsMetaData.FileFormats.NanoMat:
             return cls.fromNano(meta.filePath, metadata=meta, lock=lock)
         elif meta.fileFormat is None:
             return cls.loadAny(meta.filePath, metadata=meta, lock=lock)
@@ -1084,7 +1085,7 @@ class ImCube(ICRawBase):
         im.close()
 
     def toTiff(self, outpath: str, dtype=np.uint16):
-        """Save the ImCube to the standard TIFF file format.
+        """Save the PwsCube to the standard TIFF file format.
 
         Args:
             outpath: The path to save the new TIFF file to.
@@ -1097,27 +1098,27 @@ class ImCube(ICRawBase):
             w.save(np.rollaxis(im, -1, 0), metadata=self.metadata.dict)
         self.metadata.metadataToJson(outpath)
 
-    def selIndex(self, start: t_.Optional[float], stop: t_.Optional[float]) -> ImCube:  # Inherit docstring
+    def selIndex(self, start: t_.Optional[float], stop: t_.Optional[float]) -> PwsCube:  # Inherit docstring
         data, index = super().selIndex(start, stop)
         md = copy.deepcopy(self.metadata)  # We are creating a copy of the metadata object because modifying the original metadata object can cause weird issues.
         assert md.dict is not self.metadata.dict
         md.dict['wavelengths'] = index
-        return ImCube(data, md)
+        return PwsCube(data, md)
 
     @staticmethod
-    def getMetadataClass() -> t_.Type[pwsdtmd.ICMetaData]:  # Inherit docstring
-        return pwsdtmd.ICMetaData
+    def getMetadataClass() -> t_.Type[pwsdtmd.PwsMetaData]:  # Inherit docstring
+        return pwsdtmd.PwsMetaData
 
     @classmethod
     def fromHdfDataset(cls, d: h5py.Dataset):
-        """Load an Imcube from an HDF5 dataset."""
+        """Load an PwsCube from an HDF5 dataset."""
         data, index, mdDict, processingStatus = cls.decodeHdf(d)
-        md = pwsdtmd.ICMetaData(mdDict, fileFormat=pwsdtmd.ICMetaData.FileFormats.Hdf)
+        md = pwsdtmd.PwsMetaData(mdDict, fileFormat=pwsdtmd.PwsMetaData.FileFormats.Hdf)
         return cls(data, md, processingStatus=processingStatus)
 
     def filterDust(self, kernelRadius: float, pixelSize: float = None) -> None:
-        """This method blurs the data of the ImCube along the X and Y dimensions. This is useful if the ImCube is being
-        used as a reference to normalize other ImCube. It helps blur out dust adn other unwanted small features.
+        """This method blurs the data of the PwsCube along the X and Y dimensions. This is useful if the PwsCube is being
+        used as a reference to normalize other PwsCube. It helps blur out dust adn other unwanted small features.
 
         Args:
             kernelRadius: The `sigma` of the gaussian kernel used for blurring. A greater value results in greater
@@ -1129,46 +1130,46 @@ class ImCube(ICRawBase):
         if pixelSize is None:
             pixelSize = self.metadata.pixelSizeUm
             if pixelSize is None:
-                raise ValueError("ImCube Metadata does not have a `pixelSizeUm` saved. please manually specify pixel size. use pixelSize=1 to make `kernelRadius in units of pixels.")
+                raise ValueError("PwsCube Metadata does not have a `pixelSizeUm` saved. please manually specify pixel size. use pixelSize=1 to make `kernelRadius in units of pixels.")
         super().filterDust(kernelRadius, pixelSize)
 
-    def normalizeByReference(self, reference: ImCube):
+    def normalizeByReference(self, reference: PwsCube):
         """Normalize the raw data of this data cube by a reference cube to result in data representing
         arbitrarily scaled reflectance.
 
         Args:
-            reference (ImCube): A reference acquisition (Usually a blank spot on a dish). The data of this acquisition will be divided by the data of the reference
+            reference (PwsCube): A reference acquisition (Usually a blank spot on a dish). The data of this acquisition will be divided by the data of the reference
         """
         logger = logging.getLogger(__name__)
         if self.processingStatus.normalizedByReference:
-            raise Exception("This ImCube has already been normalized by a reference.")
+            raise Exception("This PwsCube has already been normalized by a reference.")
         if not self.processingStatus.cameraCorrected:
-            logger.warning("This ImCube has not been corrected for camera effects. This is highly reccomended before performing any analysis steps.")
+            logger.warning("This PwsCube has not been corrected for camera effects. This is highly reccomended before performing any analysis steps.")
         if not self.processingStatus.normalizedByExposure:
-            logger.warning("This ImCube has not been normalized by exposure. This is highly reccomended before performing any analysis steps.")
+            logger.warning("This PwsCube has not been normalized by exposure. This is highly reccomended before performing any analysis steps.")
         if not reference.processingStatus.cameraCorrected:
-            logger.warning("The reference ImCube has not been corrected for camera effects. This is highly reccomended before performing any analysis steps.")
+            logger.warning("The reference PwsCube has not been corrected for camera effects. This is highly reccomended before performing any analysis steps.")
         if not reference.processingStatus.normalizedByExposure:
-            logger.warning("The reference ImCube has not been normalized by exposure. This is highly reccomended before performing any analysis steps.")
+            logger.warning("The reference PwsCube has not been normalized by exposure. This is highly reccomended before performing any analysis steps.")
         self.data = self.data / reference.data
         self.processingStatus.normalizedByReference = True
 
     def subtractExtraReflection(self, extraReflection: ExtraReflectionCube):  # Inherit docstring
         assert self.data.shape == extraReflection.data.shape
         if not self.processingStatus.normalizedByExposure:
-            raise Exception("This ImCube has not yet been normalized by exposure. Are you sure you want to subtract system reflectance before doing this?")
+            raise Exception("This PwsCube has not yet been normalized by exposure. Are you sure you want to subtract system reflectance before doing this?")
         if not self.processingStatus.extraReflectionSubtracted:
             self.data = self.data - extraReflection.data
             self.processingStatus.extraReflectionSubtracted = True
         else:
-            raise Exception("The ImCube has already has extra reflection subtracted.")
+            raise Exception("The PwsCube has already has extra reflection subtracted.")
 
     def __repr__(self):
         return f"{self.__class__.__name__}(id={self.metadata.idTag})"
 
 
 class KCube(ICBase):
-    """A class representing an ImCube after being transformed from being described in terms of wavelength to
+    """A class representing an PwsCube after being transformed from being described in terms of wavelength to
     wavenumber (k-space). Much of the analysis operated in terms of k-space.
 
     Args:
@@ -1180,18 +1181,18 @@ class KCube(ICBase):
 
     _hdfTypeName = "KCube"  # This is used for saving/loading from HDF. Important not to change it or old files will stop working.
 
-    def __init__(self, data: np.ndarray, wavenumbers: t_.Tuple[float], metadata: pwsdtmd.ICMetaData = None):
-        self.metadata = metadata #Just saving a reference to the original imcube in case we want to reference it.
+    def __init__(self, data: np.ndarray, wavenumbers: t_.Tuple[float], metadata: pwsdtmd.PwsMetaData = None):
+        self.metadata = metadata #Just saving a reference to the original PwsCube in case we want to reference it.
         ICBase.__init__(self, data, wavenumbers, dtype=np.float32)
 
     @classmethod
-    def fromImCube(cls, cube: ImCube) -> KCube:
+    def fromPwsCube(cls, cube: PwsCube) -> KCube:
         """
-        Convert an ImCube into a KCube. Data is converted from wavelength to wavenumber (1/lambda), interpolation is
+        Convert an PwsCube into a KCube. Data is converted from wavelength to wavenumber (1/lambda), interpolation is
         then used to linearize the data in terms of wavenumber.
 
         Args:
-            cube: The `ImCube` object to generate a `KCube` object from.
+            cube: The `PwsCube` object to generate a `KCube` object from.
 
         Returns:
             A new instance of `KCube`
@@ -1211,13 +1212,13 @@ class KCube(ICBase):
     def wavenumbers(self) -> t_.Tuple[float, ...]:
         return self.index
 
-    def getOpd(self, isHannWindow: bool, indexOpdStop: int = None, mask: np.ndarray = None) -> t_.Tuple[np.ndarray, np.ndarray]:
+    def getOpd(self, useHannWindow: bool, indexOpdStop: int = None, mask: np.ndarray = None) -> t_.Tuple[np.ndarray, np.ndarray]:
         """
         Calculate the Fourier transform of each spectra. This can be used to get the distance (in terms of OPD) to
         objects that are reflecting light.
 
         Args:
-            isHannWindow: If True, apply a Hann window to the data before the FFT. This reduces spectral resolution but
+            useHannWindow: If True, apply a Hann window to the data before the FFT. This reduces spectral resolution but
                 improves dynamic range and reduces "frequency leakage".
             indexOpdStop: This parameter is a holdover from the original MATLAB implementation. Truncates the 3rd axis
                 of the OPD array.
@@ -1228,31 +1229,27 @@ class KCube(ICBase):
                 2D slice along the 3rd axis of the `opd` data.
 
         """
-        dataLength = self.data.shape[2]
-        opd = _FFTHelper.getFFTMagnitude(self.data, isHannWindow, normalization=_FFTHelper.Normalization.POWER)
+        opd = _FFTHelper.getFFTMagnitude(self.data, useHannWindow, normalization=_FFTHelper.Normalization.POWER)
         fftSize = opd.shape[-1]  # Due to FFT interpolation the FFT will be longer than the original data.
 
         # Isolate the desired values in the OPD.
         opd = opd[:, :, :indexOpdStop]
 
-        if not mask is None:
+        if mask is not None:  # Get the average opd within the ROI of the bool array `mask`
             opd = opd[mask].mean(axis=0)
 
+        # Generate the opd values for the current OPD.
         dk = self.wavenumbers[1] - self.wavenumbers[0]  # The interval that our linear array of wavenumbers is spaced by. Units: radians / micron
-
-        # Generate the xval for the current OPD.
-        maxOpd = 2 * np.pi / dk  # This is the maximum OPD value we can get with. tighter wavenumber spacing increases OPD range. units of microns
-        dOpd = maxOpd / dataLength  # The interval we want between values in our opd vector.
-        opdVals = dataLength / 2 * np.array(range(fftSize)) * dOpd / fftSize
-        # The above line is how it was written in the matlab code. Couldn't it be simplified down to maxOpd * np.linspace(0, 1, num = fftSize // 2 + 1) / 2 ? I'm not sure what the 2 means though.
+        maxFrequency = 1 / (dk * 2)  # Max resolvable frequency is half of the sampling frequency. Units: microns / radian
+        maxOpd = 2 * np.pi * maxFrequency  # Convert to units of microns. This is the maximum OPD value we can get with our sample interval. tighter wavenumber spacing increases OPD range. units of microns
+        opdVals = np.linspace(0, maxOpd, num=fftSize)
 
         # Above is how the old MATLAB code calculated the frequencies. IMO the code below is simpler and more understandable but we'll stick with the old code.
-        # opdVals = np.fft.rfftfreq(fftSize, dk)  # Units: cycles / (radians/microns), equivalent to microns / (radians/cycles)
-        # opdVals *= 2 * np.pi  # Units: microns
+        # opdVals = 2 * np.pi * np.fft.rfftfreq(fftSize, dk)  # Units: microns
 
         opdVals = opdVals[:indexOpdStop]
 
-        opd = opd.astype(self.data.dtype) #Make sure to upscale precision
+        opd = opd.astype(self.data.dtype)  # Make sure to upscale precision
         opdVals = opdVals.astype(self.data.dtype)
         return opd, opdVals
 
@@ -1270,14 +1267,9 @@ class KCube(ICBase):
         Returns:
             A 2d numpy array of the signal RMS at each XY location in the image.
         """
-        data = self.data - self.data.mean(axis=2)[:, :, None]  # Subtract the mean from every pixel so we are only measuring variance.
-        opd = _FFTHelper.getFFTMagnitude(data, useHannWindow, normalization=_FFTHelper.Normalization.POWER)
-        dk = self.wavenumbers[1] - self.wavenumbers[0]  # Units of radians / microns
-        opdIndex = np.fft.rfftfreq(opd.shape[2], dk)  # Units of microns / (radians / cycles)
-        opdIndex *= 2 * np.pi  # Units of microns
+        opd, opdIndex = self.getOpd(useHannWindow=useHannWindow)
         startOpdIdx = np.argmin(np.abs(opdIndex - lowerOPD))  # The index associated with lowerOPD
         stopOpdIdx = np.argmin(np.abs(opdIndex - upperOPD))  # The index associated with upperOPD
-        print(stopOpdIdx, startOpdIdx)
         opdSquaredSum = np.sum(opd[:, :, startOpdIdx:stopOpdIdx+1] ** 2, axis=2)  # Parseval's theorem tells us that this is equivalent to the sum of the squares of our original signal
         opdSquaredSum *= len(self.wavenumbers) / opd.shape[2]  # If the original data and opd were of the same length then the above line would be correct. Since the fft may have been upsampled. we need to normalize.
         return np.sqrt(opdSquaredSum)
@@ -1432,13 +1424,13 @@ class FluorescenceImage:
         self.metadata = md
 
     @classmethod
-    def fromTiff(cls, directory: str, acquisitionDirectory: t_.Optional[pwsdtmd.AcqDir] = None) -> FluorescenceImage:
+    def fromTiff(cls, directory: str, acquisitionDirectory: t_.Optional[pwsdtmd.Acquisition] = None) -> FluorescenceImage:
         """
         Load an image from a TIFF file.
 
         Args:
             directory: The path to the folder containing the TIFF file.
-            acquisitionDirectory: The `AcqDir` object associated with this acquisition.
+            acquisitionDirectory: The `Acquisition` object associated with this acquisition.
 
         Returns:
             A new instanse of `FluorescenceImage`.
