@@ -33,12 +33,13 @@ import jsonschema
 import numpy as np
 import tifffile as tf
 from scipy import io as spio
-from pwspy.analysis import AbstractHDFAnalysisResults
 from pwspy.dataTypes import _jsonSchemasPath
 from pwspy.dataTypes._other import CameraCorrection, Roi, RoiFile
 import pwspy.dataTypes._data as pwsdtd
 from pwspy import dateTimeFormat
 from pwspy.utility.misc import cached_property
+if t_.TYPE_CHECKING:
+    from pwspy.analysis import AbstractHDFAnalysisResults
 
 
 class MetaDataBase(abc.ABC):
@@ -48,7 +49,7 @@ class MetaDataBase(abc.ABC):
     Args:
         metadata: A dictionary containing the metadata
         filePath: The path to the location the metadata was loaded from
-        acquisitionDirectory: A reference to the `AcqDir` associated with this object.
+        acquisitionDirectory: A reference to the `Acquisition` associated with this object.
 
     """
 
@@ -65,12 +66,12 @@ class MetaDataBase(abc.ABC):
         This serves as a schematic that can be checked against when loading metadata to make sure it contains the required information."""
         pass
 
-    def __init__(self, metadata: dict, filePath: Optional[str] = None, acquisitionDirectory: Optional[AcqDir] = None):
+    def __init__(self, metadata: dict, filePath: t_.Optional[str] = None, acquisitionDirectory: t_.Optional[Acquisition] = None):
         logger = logging.getLogger(__name__)
         self.filePath = filePath
         self.acquisitionDirectory = acquisitionDirectory
         refResolver = jsonschema.RefResolver(pathlib.Path(self._jsonSchemaPath).as_uri(), None)  # This resolver is used to allow derived json schemas to refer to the base schema.
-        jsonschema.validate(instance=metadata, schema=self._jsonSchema, types={'array': (list, tuple)}, resolver=refResolver)
+        jsonschema.validate(instance=metadata, schema=self._jsonSchema, resolver=refResolver, cls=_TupleValidator)
         self.dict: dict = metadata
         try:
             datetime.strptime(self.dict['time'], dateTimeFormat)
@@ -85,7 +86,7 @@ class MetaDataBase(abc.ABC):
             logger.warning("The `system` name in the metadata is blank. Check that the PWS System is saving the proper calibration values.")
         if all([i in self.dict for i in ['darkCounts', 'linearityPoly']]):
             if self.dict['darkCounts'] == 0:
-                logger.warning("Detected a darkCounts value of 0 in the pwsdtd.ImCube Metadata. Check that the PWS System is saving the proper calibration values.")
+                logger.warning("Detected a darkCounts value of 0 in the pwsdtd.PwsCube Metadata. Check that the PWS System is saving the proper calibration values.")
             self.cameraCorrection = CameraCorrection(darkCounts=self.dict['darkCounts'],
                                                      linearityPolynomial=self.dict['linearityPoly'])
         else:
@@ -100,6 +101,7 @@ class MetaDataBase(abc.ABC):
         """
         pass
 
+    @property
     @abc.abstractmethod
     def idTag(self) -> str:
         """A string that uniquely identifies this data."""
@@ -164,7 +166,7 @@ class AnalysisManager(abc.ABC):
     Args:
         metadata: A dictionary containing the metadata
         filePath: The path to the location the metadata was loaded from
-        acquisitionDirectory: A reference to the `AcqDir` associated with this object.
+        acquisitionDirectory: A reference to the `Acquisition` associated with this object.
 
     """
     def __init__(self, filePath: str):
@@ -256,7 +258,7 @@ class DynMetaData(MetaDataBase, AnalysisManager):
     with open(_jsonSchemaPath) as f:
         _jsonSchema = json.load(f)
 
-    def __init__(self, metadata: dict, filePath: Optional[str] = None, fileFormat: Optional[FileFormats] = None, acquisitionDirectory: Optional[AcqDir] = None):
+    def __init__(self, metadata: dict, filePath: t_.Optional[str] = None, fileFormat: t_.Optional[FileFormats] = None, acquisitionDirectory: t_.Optional[Acquisition] = None):
         self.fileFormat = fileFormat
         MetaDataBase.__init__(self, metadata, filePath, acquisitionDirectory=acquisitionDirectory)
         AnalysisManager.__init__(self, filePath)
@@ -286,12 +288,12 @@ class DynMetaData(MetaDataBase, AnalysisManager):
         return self.dict['wavelength']
 
     @property
-    def times(self) -> Tuple[float, ...]:
+    def times(self) -> t_.Tuple[float, ...]:
         """A sequence indicatin the time associated with each 2D slice of the 3rd axis of the `data` array"""
         return self.dict['times']
 
     @classmethod
-    def fromOldPWS(cls, directory: str, lock: mp.Lock = None, acquisitionDirectory: Optional[AcqDir] = None) -> DynMetaData:
+    def fromOldPWS(cls, directory: str, lock: mp.Lock = None, acquisitionDirectory: t_.Optional[Acquisition] = None) -> DynMetaData:
         """Loads old dynamics cubes which were saved the same as old pws cubes. a raw binary file with some metadata saved in random .mat files. Does not support
         automatic detection of binning, pixel size, camera dark counts, system name.
 
@@ -329,7 +331,7 @@ class DynMetaData(MetaDataBase, AnalysisManager):
         return cls(md, filePath=directory, fileFormat=DynMetaData.FileFormats.RawBinary, acquisitionDirectory=acquisitionDirectory)
 
     @classmethod
-    def fromTiff(cls, directory, lock: mp.Lock = None, acquisitionDirectory: Optional[AcqDir] = None) -> DynMetaData:
+    def fromTiff(cls, directory, lock: mp.Lock = None, acquisitionDirectory: t_.Optional[Acquisition] = None) -> DynMetaData:
         """
 
         Args:
@@ -368,10 +370,10 @@ class ERMetaData:
     to keep track of a ExtraReflectanceCube without having to have the data from the file loaded into memory.
 
     Args:
-        inheritedMetadata: The metadata dictionary will often just be inherited information from one of the `ImCubes` that was used to create
+        inheritedMetadata: The metadata dictionary will often just be inherited information from one of the `PwsCubes` that was used to create
             this ER Cube. While this data can be useful it should be taken with a grain of salt. E.G. the metadata will contain
-            an `exposure` field. In reality this ER Cube will have been created from pwsdtd.ImCubes at a variety of exposures.
-        numericalAperture: The numerical aperture that the ImCubes used to generate this Extra reflection cube were imaged at.
+            an `exposure` field. In reality this ER Cube will have been created from pwsdtd.PwsCubes at a variety of exposures.
+        numericalAperture: The numerical aperture that the PwsCubes used to generate this Extra reflection cube were imaged at.
         filePath: The path to the file that this object is stored in.
     """
     _jsonSchema = {"$schema": "http://json-schema.org/schema#",
@@ -394,10 +396,10 @@ class ERMetaData:
     DATASETTAG = 'extraReflection'
     _MDTAG = 'metadata'
 
-    def __init__(self, inheritedMetadata: dict, numericalAperture: float, filePath: str=None):
+    def __init__(self, inheritedMetadata: dict, numericalAperture: float, filePath: str = None):
         self.inheritedMetadata = inheritedMetadata
         self.inheritedMetadata['numericalAperture'] = numericalAperture
-        jsonschema.validate(instance=inheritedMetadata, schema=self._jsonSchema, types={'array': (list, tuple)})
+        jsonschema.validate(instance=inheritedMetadata, schema=self._jsonSchema, cls=_TupleValidator)
         self.filePath = filePath
 
     @property
@@ -416,7 +418,7 @@ class ERMetaData:
         return self.inheritedMetadata['system']
 
     @classmethod
-    def validPath(cls, path: str) -> Tuple[bool, Union[str, bytes], Union[str, bytes]]:
+    def validPath(cls, path: str) -> t_.Tuple[bool, t_.Union[str, bytes], t_.Union[str, bytes]]:
         """
 
         Args:
@@ -473,7 +475,7 @@ class ERMetaData:
         return g
 
     @classmethod
-    def directory2dirName(cls, path: str) -> Tuple[Union[bytes, str], Union[bytes, str]]:
+    def directory2dirName(cls, path: str) -> t_.Tuple[t_.Union[bytes, str], t_.Union[bytes, str]]:
         """
 
         Args:
@@ -511,7 +513,7 @@ class FluorMetaData(MetaDataBase):
     with open(_jsonSchemaPath) as f:
         _jsonSchema = json.load(f)
 
-    def __init__(self, md: dict, filePath: Optional[str] = None, acquisitionDirectory: Optional[AcqDir] = None):
+    def __init__(self, md: dict, filePath: t_.Optional[str] = None, acquisitionDirectory: t_.Optional[Acquisition] = None):
         super().__init__(md, filePath, acquisitionDirectory)
 
     def toDataClass(self, lock: mp.Lock = None) -> pwsdtd.FluorescenceImage:
@@ -522,7 +524,7 @@ class FluorMetaData(MetaDataBase):
         return f"Fluor_{self.dict['system']}_{self.dict['time']}"
 
     @classmethod
-    def fromTiff(cls, directory: str, acquisitionDirectory: Optional[AcqDir]) -> FluorMetaData:
+    def fromTiff(cls, directory: str, acquisitionDirectory: t_.Optional[Acquisition]) -> FluorMetaData:
         """Load from a TIFF file.
 
         Args:
@@ -572,7 +574,7 @@ class FluorMetaData(MetaDataBase):
             return f.asarray()
 
 
-class ICMetaData(MetaDataBase, AnalysisManager):
+class PwsMetaData(MetaDataBase, AnalysisManager):
     """A class that represents the metadata of a PWS acquisition.
 
     Args:
@@ -589,57 +591,57 @@ class ICMetaData(MetaDataBase, AnalysisManager):
         from pwspy.analysis.pws import PWSAnalysisResults
         return PWSAnalysisResults
 
-    _jsonSchemaPath = os.path.join(_jsonSchemasPath, 'ICMetaData.json')
+    _jsonSchemaPath = os.path.join(_jsonSchemasPath, 'PwsMetaData.json')
     with open(_jsonSchemaPath) as f:
         _jsonSchema = json.load(f)
 
-    def __init__(self, metadata: dict, filePath: Optional[str] = None, fileFormat: ICMetaData.FileFormats = None, acquisitionDirectory: Optional[AcqDir] = None):
+    def __init__(self, metadata: dict, filePath: t_.Optional[str] = None, fileFormat: PwsMetaData.FileFormats = None, acquisitionDirectory: t_.Optional[Acquisition] = None):
         MetaDataBase.__init__(self, metadata, filePath, acquisitionDirectory=acquisitionDirectory)
         AnalysisManager.__init__(self, filePath)
-        self.fileFormat: ICMetaData.FileFormats = fileFormat
+        self.fileFormat: PwsMetaData.FileFormats = fileFormat
         self.dict['wavelengths'] = tuple(np.array(self.dict['wavelengths']).astype(float))
 
-    def toDataClass(self, lock: mp.Lock = None) -> pwsdtd.ImCube:
-        return pwsdtd.ImCube.fromMetadata(self, lock)
+    def toDataClass(self, lock: mp.Lock = None) -> pwsdtd.PwsCube:
+        return pwsdtd.PwsCube.fromMetadata(self, lock)
 
     @cached_property
     def idTag(self) -> str:
-        return f"ImCube_{self.dict['system']}_{self.dict['time']}"
+        return f"PwsCube_{self.dict['system']}_{self.dict['time']}"
 
     @property
-    def wavelengths(self) -> Tuple[float, ...]:
+    def wavelengths(self) -> t_.Tuple[float, ...]:
         return self.dict['wavelengths']
 
     @classmethod
-    def loadAny(cls, directory, lock: mp.Lock = None, acquisitionDirectory: Optional[AcqDir] = None) -> ICMetaData:
+    def loadAny(cls, directory, lock: mp.Lock = None, acquisitionDirectory: t_.Optional[Acquisition] = None) -> PwsMetaData:
         """
         Attempt to load from any file format.
 
         Args:
             directory: The file path to load the metadata from.
         Returns:
-            A new instance of `ICMetaData` loaded from file
+            A new instance of `PwsMetaData` loaded from file
         """
         try:
-            return ICMetaData.fromTiff(directory, lock=lock, acquisitionDirectory=acquisitionDirectory)
+            return PwsMetaData.fromTiff(directory, lock=lock, acquisitionDirectory=acquisitionDirectory)
         except:
             try:
-                return ICMetaData.fromOldPWS(directory, lock=lock, acquisitionDirectory=acquisitionDirectory)
+                return PwsMetaData.fromOldPWS(directory, lock=lock, acquisitionDirectory=acquisitionDirectory)
             except:
                 try:
-                    return ICMetaData.fromNano(directory, lock=lock, acquisitionDirectory=acquisitionDirectory)
+                    return PwsMetaData.fromNano(directory, lock=lock, acquisitionDirectory=acquisitionDirectory)
                 except:
                     raise OSError(f"Could not find a valid PWS image cube file at {directory}.")
 
     @classmethod
-    def fromOldPWS(cls, directory, lock: mp.Lock = None, acquisitionDirectory: Optional[AcqDir] = None) -> ICMetaData:
+    def fromOldPWS(cls, directory, lock: mp.Lock = None, acquisitionDirectory: t_.Optional[Acquisition] = None) -> PwsMetaData:
         """
         Attempt to load from the old .mat file format.
 
         Args:
             directory: The file path to load the metadata from.
         Returns:
-            A new instance of `ICMetaData` loaded from file
+            A new instance of `PwsMetaData` loaded from file
         """
         if lock is not None:
             lock.acquire()
@@ -661,17 +663,17 @@ class ICMetaData(MetaDataBase, AnalysisManager):
         finally:
             if lock is not None:
                 lock.release()
-        return cls(md, filePath=directory, fileFormat=ICMetaData.FileFormats.RawBinary, acquisitionDirectory=acquisitionDirectory)
+        return cls(md, filePath=directory, fileFormat=PwsMetaData.FileFormats.RawBinary, acquisitionDirectory=acquisitionDirectory)
 
     @classmethod
-    def fromNano(cls, directory: str, lock: mp.Lock = None, acquisitionDirectory: Optional[AcqDir] = None) -> ICMetaData:
+    def fromNano(cls, directory: str, lock: mp.Lock = None, acquisitionDirectory: t_.Optional[Acquisition] = None) -> PwsMetaData:
         """
         Attempt to load from NanoCytomic .mat file format
 
         Args:
             directory: The file path to load the metadata from.
         Returns:
-            A new instance of `ICMetaData` loaded from file
+            A new instance of `PwsMetaData` loaded from file
         """
         if lock is not None:
             lock.acquire()
@@ -687,17 +689,17 @@ class ICMetaData(MetaDataBase, AnalysisManager):
         finally:
             if lock is not None:
                 lock.release()
-        return cls(md, filePath=directory, fileFormat=ICMetaData.FileFormats.NanoMat, acquisitionDirectory=acquisitionDirectory)
+        return cls(md, filePath=directory, fileFormat=PwsMetaData.FileFormats.NanoMat, acquisitionDirectory=acquisitionDirectory)
 
     @classmethod
-    def fromTiff(cls, directory, lock: mp.Lock = None, acquisitionDirectory: Optional[AcqDir] = None) -> ICMetaData:
+    def fromTiff(cls, directory, lock: mp.Lock = None, acquisitionDirectory: t_.Optional[Acquisition] = None) -> PwsMetaData:
         """
         Attempt to load from the standard TIFF file format.
 
         Args:
             directory: The file path to load the metadata from.
         Returns:
-            A new instance of `ICMetaData` loaded from file
+            A new instance of `PwsMetaData` loaded from file
         """
         if lock is not None:
             lock.acquire()
@@ -720,7 +722,7 @@ class ICMetaData(MetaDataBase, AnalysisManager):
         finally:
             if lock is not None:
                 lock.release()
-        if 'MicroManagerMetadata' not in metadata:  # Data saved by something other than the Micro-Manager acquisition plugin won't have this. I.E. NanoCytomics  data saved by `toTiff`
+        if 'MicroManagerMetadata' not in metadata:  # Data saved by something other than the Micro-Manager acquisition plugin won't have this. I.E. NC  data saved by `toTiff`
             binning = metadata['binning']
             pixelSize = metadata['pixelSizeUm']
         else:
@@ -742,7 +744,7 @@ class ICMetaData(MetaDataBase, AnalysisManager):
         if 'waveLengths' in metadata:  # Fix an old naming issue
             metadata['wavelengths'] = metadata['waveLengths']
             del metadata['waveLengths']
-        return cls(metadata, filePath=directory, fileFormat=ICMetaData.FileFormats.Tiff, acquisitionDirectory=acquisitionDirectory)
+        return cls(metadata, filePath=directory, fileFormat=PwsMetaData.FileFormats.Tiff, acquisitionDirectory=acquisitionDirectory)
 
     def metadataToJson(self, directory):
         """
@@ -761,7 +763,7 @@ class ICMetaData(MetaDataBase, AnalysisManager):
         Returns:
             An image for quick viewing of the acquisition. No numerical significance.
         """
-        if self.fileFormat == ICMetaData.FileFormats.NanoMat:
+        if self.fileFormat == PwsMetaData.FileFormats.NanoMat:
             with h5py.File(os.path.join(self.filePath, 'image_bd.mat'), 'r') as hf:
                 return np.array(hf['image_bd']).T.copy()  # For some reason these are saved transposed?
         else:
@@ -769,7 +771,7 @@ class ICMetaData(MetaDataBase, AnalysisManager):
                 return f.asarray()
 
 
-class AcqDir:
+class Acquisition:
     """This class handles the file structure of a single acquisition. this can include a PWS acquisition as well as colocalized Dynamics and fluorescence.
 
     Args:
@@ -789,18 +791,18 @@ class AcqDir:
         return f"{self.__class__.__name__}({path})"
 
     @cached_property
-    def pws(self) -> Optional[ICMetaData]:
-        """ICMetaData: Returns None if no PWS acquisition was found."""
+    def pws(self) -> t_.Optional[PwsMetaData]:
+        """PwsMetaData: Returns None if no PWS acquisition was found."""
         try:
-            return ICMetaData.loadAny(os.path.join(self.filePath, 'PWS'), acquisitionDirectory=self)
+            return PwsMetaData.loadAny(os.path.join(self.filePath, 'PWS'), acquisitionDirectory=self)
         except:
             try:
-                return ICMetaData.loadAny(os.path.join(self.filePath), acquisitionDirectory=self) #Many of the old files are saved here in the root directory.
+                return PwsMetaData.loadAny(os.path.join(self.filePath), acquisitionDirectory=self) #Many of the old files are saved here in the root directory.
             except:
                 return None
 
     @cached_property
-    def dynamics(self) -> Optional[DynMetaData]:
+    def dynamics(self) -> t_.Optional[DynMetaData]:
         """DynMetaData: Returns None if no dynamics acquisition was found."""
         try:
             return DynMetaData.fromTiff(os.path.join(self.filePath, 'Dynamics'), acquisitionDirectory=self)
@@ -812,7 +814,7 @@ class AcqDir:
 
     @cached_property
     def fluorescence(self) -> t_.List[FluorMetaData]:
-        # Newer acquisitions allow for multiple fluorescence images saved to numbered subfolders
+        """List[FluorMetaData]: Newer acquisitions allow for multiple fluorescence images saved to numbered subfolders"""
         i = 0
         imgs = []
         while True:
@@ -841,7 +843,7 @@ class AcqDir:
         else: #We must have one of these two items.
             return self.dynamics.idTag
 
-    def getRois(self) -> List[Tuple[str, int, RoiFile.FileFormats]]:
+    def getRois(self) -> t_.List[t_.Tuple[str, int, RoiFile.FileFormats]]:
         """Return information about the Rois found in the acquisition's file path.
         See documentation for Roi.getValidRoisInPath()"""
         assert self.filePath is not None
@@ -864,7 +866,23 @@ class AcqDir:
             return RoiFile.loadAny(self.filePath, name, num, acquisition=self)
 
     def saveRoi(self, roiName: str, roiNumber: int, roi: Roi, overwrite: bool = False) -> RoiFile:
-        """Save a Roi to file in the acquisition's file path."""
+        """
+        Save a Roi to file in the acquisition's file path.
+
+        Args:
+            roiName: The name to identify this ROI
+            roiNumber: The number to identify this ROI
+            roi: The ROI object defining the ROI geometry
+            overwrite: If True then any existing ROIFile matching this name and number will be overwritten. Otherwise an OSError is raised.
+
+        Returns:
+            A reference to the new ROIFile
+
+        Raises:
+            OSError: If `overwrite` is False and an ROI of the same name and number
+        already exists then an OSError will be raised.
+
+        """
         return RoiFile.toHDF(roi, roiName, roiNumber, self.filePath, overwrite=overwrite, acquisition=self)
 
     def deleteRoi(self, name: str, num: int, fformat: t_.Optional[RoiFile.FileFormats] = None):
@@ -917,10 +935,18 @@ class AcqDir:
     def __hash__(self) -> int:
         return hash(self.filePath)  # Since the class is intimiately tied to the filesystem this is all that makes it unique
 
-    def __eq__(self, other: AcqDir) -> bool:
-        if not isinstance(other, AcqDir):
+    def __eq__(self, other: Acquisition) -> bool:
+        if not isinstance(other, Acquisition):
             return False
         return self.filePath == other.filePath
 
+
+_TupleValidator = jsonschema.validators.extend(  # All of this is just so that jsonschema will allow a tuple as a 'array' schema member.
+    jsonschema.Draft7Validator,
+    type_checker=jsonschema.Draft7Validator.TYPE_CHECKER.redefine(
+        'array',
+        lambda checker, instance: jsonschema.Draft7Validator.TYPE_CHECKER.is_type(instance, 'array') or isinstance(instance, tuple)
+    ))
+
 if __name__ == '__main__':
-    md = ICMetaData.fromNano(r'C:\Users\nicke\Desktop\LTL20b_Tracking cells in 50%EtOH,95%EtOH,Water\95% ethanol\Cell1')
\ No newline at end of file
+    md = PwsMetaData.fromNano(r'C:\Users\nicke\Desktop\LTL20b_Tracking cells in 50%EtOH,95%EtOH,Water\95% ethanol\Cell1')
\ No newline at end of file
