@@ -32,7 +32,7 @@ Classes
    :toctree: generated/
 
    RuntimeSequenceSettings
-   SeqAcqDir
+   SequenceAcquisition
    SequencerCoordinate
    SequencerCoordinateRange
    SequencerStep
@@ -44,7 +44,7 @@ Classes
 
 Inheritance
 -------------
-.. inheritance-diagram:: SequencerStep CoordSequencerStep ZStackStep TimeStep PositionsStep ContainerStep RuntimeSequenceSettings SeqAcqDir SequencerCoordinate SequencerCoordinateRange
+.. inheritance-diagram:: TreeItem SequencerStep IterableSequencerStep ZStackStep TimeStep PositionsStep ContainerStep RuntimeSequenceSettings SequenceAcquisition SequencerCoordinate SequencerCoordinateRange
     :parts: 1
 
 """
@@ -56,13 +56,13 @@ from pwspy.utility.acquisition.steps import RuntimeSequenceSettings
 
 from .steps import SequencerStep, IterableSequencerStep, ZStackStep, TimeStep, PositionsStep, ContainerStep
 from ._treeItem import TreeItem
-from .sequencerCoordinate import SeqAcqDir, SequencerCoordinate, SequencerCoordinateRange
+from .sequencerCoordinate import SequenceAcquisition, SequencerCoordinate, SequencerCoordinateRange
 import os
 import pwspy.dataTypes as pwsdt
 from glob import glob
 
 
-def loadDirectory(directory: str) -> t_.Tuple[SequencerStep, t_.List[SeqAcqDir]]:
+def loadDirectory(directory: os.PathLike) -> t_.Tuple[SequencerStep, t_.List[SequenceAcquisition]]:
     """
     If `directory` contains a dataset acquired with the acquisition sequencer then this function will return a python
     object representing the sequence settings and a list of references to the acquisitions that are part of the sequence.
@@ -73,7 +73,7 @@ def loadDirectory(directory: str) -> t_.Tuple[SequencerStep, t_.List[SeqAcqDir]]
     Returns:
         A tuple containing:
             The Root `SequencerStep` of the acquisition sequence.
-            A list of `SeqAcqDir` objects belonging to the sequence.
+            A list of `SequenceAcquisition` objects belonging to the sequence.
     """
     rtSeq = RuntimeSequenceSettings.fromJsonFile(directory)
     if rtSeq.uuid is None:
@@ -83,7 +83,7 @@ def loadDirectory(directory: str) -> t_.Tuple[SequencerStep, t_.List[SeqAcqDir]]
     acqs = []
     for f in files:
         try:
-            acqs.append(SeqAcqDir(pwsdt.AcqDir(f)))
+            acqs.append(SequenceAcquisition(pwsdt.Acquisition(f)))
         except FileNotFoundError:
             pass  # There may be "Cell" folders that don't contain a sequencer coordinate.
     acqs = [acq for acq in acqs if acq.sequencerCoordinate.uuid == rtSeq.uuid]  # Filter out acquisitions that don't have a matching UUID to the sequence file.
