@@ -16,7 +16,8 @@
 # along with PWSpy.  If not, see <https://www.gnu.org/licenses/>.
 
 # -*- coding: utf-8 -*-
-"""Provides a number of functions for calculating simple reflections based on known refractive indices
+"""
+Provides a number of functions for calculating simple reflections based on known refractive indices
 
 Functions
 ----------
@@ -36,12 +37,12 @@ from numbers import Number
 import pandas as pd
 import numpy as np
 import os
-from . import Material
+from pwspy.utility.reflection import Material
 
-from .multilayerReflectanceEngine import Stack, Layer, Polarization
+from pwspy.utility.reflection.multilayerReflectanceEngine import Stack, Layer, Polarization
 from typing import Union, List, Tuple
 
-
+# File paths for materials that have the N values stored in csv.
 materialFiles = {
     Material.Glass: 'N-BK7.csv',
     Material.Water: 'Daimon-21.5C.csv',
@@ -55,6 +56,11 @@ materialFiles = {
     Material.Methanol: 'Moutzouris.csv'
 }
 
+# Coefficients for materials that use the Cauchy equation
+materialCoeffs = {
+    Material.Glycerol_99_5: (1.45797, 0.00598, -0.00036)  # 1.45797+0.00598λ−2−0.00036λ−4. Rheims et al. 1997: n 0.589-1.05 µm
+}
+
 
 def _init():
     """This function initializes data from files when the module is imported."""
@@ -72,13 +78,24 @@ def _init():
     for k, v in ser.items():
         first += [v.first_valid_index()]
         last += [v.last_valid_index()]
-    first = max(first)
-    last = min(last)
+    first = max(first)  # The lowest wavelength we have data for all materials.
+    last = min(last)  # The higherst wavelength we have data for all materials.
     # Interpolate so we don't have any nan values.
     #    df = pd.DataFrame(ser)
     df = pd.concat(ser, axis='columns', keys=materialFiles.keys())
     df = df.interpolate('index')
-    return df.loc[first:last]
+    df = df.loc[first:last]  # Crop to the first and last wavelengths that we have data for all materials.
+
+    # Calculate from the cauchy Equation
+    wavelengths = df.index / 1e3  # Convert to microns
+    for name, coeffs in materialCoeffs.items():
+        arr = np.zeros((len(wavelengths),))
+        for i, coeff in enumerate(coeffs):
+            arr += coeff / (wavelengths ** (i*2))
+        df[(name, 'n')] = arr
+        df[(name, 'k')] = 0
+
+    return df
 
 _n = _init()
 del _init
@@ -107,13 +124,15 @@ def getRefractiveIndex(mat: Material, wavelengths: typing.Optional[typing.Iterab
     return refractiveIndex
 
 
-def getReflectance(mat1: Material, mat2: Material, wavelengths: Union[np.ndarray, List, Tuple] = None, NA: float = 0) -> pd.Series:
+def getReflectance(mat1: Union[Number, pd.Series, Material], mat2: Union[Number, pd.Series, Material], wavelengths: Union[np.ndarray, List, Tuple] = None, NA: float = 0) -> pd.Series:
     """Given the names of two interfaces this provides the reflectance in units of percent.
     If given a series as wavelengths the data will be interpolated and reindexed to match the wavelengths.
 
     Args:
-        mat1: The first material comprising the reflective interface.
-        mat2: The second material comprising the reflective interface.
+        mat1: The first material comprising the reflective interface. This can either be a number or series of numbers representing the refractive index at different wavelengths
+            or it can be a `Material` in which case the refractive index will be automatically calculated.
+        mat2: The second material comprising the reflective interface. This can either be a number or series of numbers representing the refractive index at different wavelengths
+            or it can be a `Material` in which case the refractive index will be automatically calculated.
         wavelengths: The wavelengths to calculate the reflectance at.
         NA: The numerical aperture of the system. Reflectance will be calculated by radially integrating results over
             the range of angles present within the numerical aperture. If left as `None` the result is calculated for
@@ -137,3 +156,6 @@ def getReflectance(mat1: Material, mat2: Material, wavelengths: Union[np.ndarray
     else:
         r = s.circularIntegration(np.linspace(0, NA, num=1000))
     return r
+
+if __name__ == '__main__':
+    a = 1
\ No newline at end of file
